@@ -184,7 +184,7 @@ emis_post <- function(arra,
       nombres <- lapply(1:dim(m)[2], function(i){paste0("h",i)})
       if(!missing(net)){
         netsf <- sf::st_as_sf(net)
-        dfsf <- sf::st_sf(Emissions(df), geometry = netsf$geometry)
+        dfsf <- sf::st_sf(Emissions(df), geometry = sf::st_geometry(netsf))
         return(dfsf)
       } else {
         return(Emissions(df))
@@ -247,7 +247,7 @@ emis_post <- function(arra,
 
       if(!missing(net)){
         netsf <- sf::st_as_sf(net)
-        dfsf <- sf::st_sf(Emissions(df), geometry = netsf$geometry)
+        dfsf <- sf::st_sf(Emissions(df), geometry = sf::st_geometry(netsf))
         return(dfsf)
       } else {
         return(Emissions(df))
